### Name: insertIntoTable
### Title: Adding new data to a database table
### Aliases: insertIntoTable
### Keywords: data

### ** Examples

## creating a connection
## Not run: Con <- dbConnect(PgSQL(),user="postgres",host="localhost",dbname="template1")

## creating a table with two attributes name and value. as third attribute
## a primary key with the name atable_pk will automatically generated.
## Not run: createDBTable(Con,name="atable",attributes=c("name","value"),data.types=c("TEXT"))

## fill some data into the table, remember that not all cells have to be
## filled.
## Not run: insertIntoTable(Con,name="atable",data=data.frame(species=c("hobbit","human"),value=c("good","bad")))

## now create a table that references this table.
## Not run: createDBTable(Con,name="btable",attributes=c("name","age"),data.types=c("TEXT"),references="atable")

## before inserting any values to this table we have to create a reference.
## the source.table.column specifies the column in the submitted data, which
## values are equal to the values in the ref.table.column attribute in the 
## referenced table.
## Not run: ref <- new("AutoReference",source.table="btable",ref.table="atable",source.table.column="aref",ref.table.column="species")

## Not run: insertIntoTable(Con,name="btable",data=data.frame(name=c("frodo","fred"),aref=c("hobbit","human"))),references=ref)

## summary:
## the function inserts in the table btable "frodo" in the attribute <name>, and
## links this row to the referenced table btable, by setting in the attribute 
## <atable_fk> (in table <btable>) the value from the primary key of the row in
## the table <atable>, where the attribute <species> has the value "hobbit".
 
## if we had submitted in the aref column a value that is not present in the
## atable, a error would be thrown and nothing is going to be written into
## the table. So the referential integrity is guaranteed. Naturally we can insert into the btable values without any reference to the atable.




